//缓存方式，为空不缓存，session：会话缓存，local:本地缓存，application：全局上下文缓存
let cacheType = "";

let currentTheme = "";

const SESSION_TYPE = "session";

const LOCAL_TYPE = "local";

const APP_TYPE = "application";

const APP_CACHE_TOKEN = "rj_theme_app_";

let token_user_id = undefined;

import { EventBus } from './event-bus.js';

/**
 * 取得当前缓存
 * @return {[type]} [description]
 */
export const getCacheTheme = () => {
	let themeTmp = '';
	switch(cacheType) {
		case SESSION_TYPE:
			themeTmp = sessionStorage.currentTheme;
			break;
		case LOCAL_TYPE:
			themeTmp = localStorage.currentTheme;
			break;
		case APP_TYPE:
			themeTmp = "";
			break;
	}
	return themeTmp||currentTheme;
};

/**
 * 所有主题
 * @type {Array}
 */
export const themes = [
	{
		name: "默认主题",
		val: "theme-12c2ab",
		themeCl: "12c2ab",
		themeIcon: "theme-icons icon--12c2ab"
	},
	{
		name: "深蓝色主题",
		val: "theme-232a45",
		themeCl: "232a45",
		themeIcon: "theme-icons icon--232a45"
	},
	{
		name: "天蓝色主题",
		val: "theme-0090ff",
		themeCl: "0090ff",
		themeIcon: "theme-icons icon--0090ff"
	},
	{
		name: "浅蓝色主题",
		val: "theme-00aeff",
		themeCl: "00aeff",
		themeIcon: "theme-icons icon--00aeff"
	}
];

/**
 * 缓存当前主题，供下次使用
 * @param  {[type]} theme [description]
 * @return {[type]}       [description]
 */
export const cacheTheme = (theme) => {
	window.$rjCurrentTheme = theme;
	switch(cacheType) {
	case SESSION_TYPE:
		sessionStorage.currentTheme = currentTheme;
		console.log("主题已缓存到当前会话，theme=?", currentTheme);
	break;
	case LOCAL_TYPE:
		localStorage.currentTheme = currentTheme;
		console.log("主题已缓存到本地，theme=?", currentTheme);
	break;
	case APP_TYPE:
		if(!token_user_id) {
			console.info("未设置当前用户，无法做全局上下文缓存!");
			return;
		}
		let token = `${APP_CACHE_TOKEN}${token_user_id}`
		console.log("主题已缓存到全局上下文，theme=?", currentTheme);
	break;
	default:
		console.log("本次主题不做缓存操作");
	}
};

let doReset = function(theme) {
	theme = theme || "theme-232a45";
	let bodyObj = document.body;
	if(bodyObj) bodyObj.setAttribute("class", theme);
	currentTheme = theme;
	EventBus.$emit('rj-theme-change', theme);
	cacheTheme(theme);
};

/**
 * 主题设置
 * @param  {[type]} theme 当前主题
 * @param  {[type]} userId 当前登录者id，用于主题上下文缓存
 */
export function resetTheme(theme, userId) {
	token_user_id = userId;
	localStorage.removeItem("currentTheme");
	sessionStorage.removeItem("currentTheme");
	doReset(theme);
};

/**
 * 初始化，标记为不缓存
 * @param  {[type]} defTheme [默认主题]
 * @return {[type]}       [description]
 */
export function initTheme(theme) {
	doReset(theme);
}

/**
 * 初始化，并标记为本地缓存
 * @param  {[type]} defTheme [默认主题]
 * @return {[type]}       [description]
 */
export function initTheme4LocalCache(theme) {
	cacheType = LOCAL_TYPE;
	doReset(getCacheTheme()||theme);
}

/**
 * 初始化，并标记为会话缓存
 * @param  {[type]} defTheme [默认主题]
 * @return {[type]}       [description]
 */
export function initTheme4SessionCache(theme) {
	cacheType = SESSION_TYPE;
	doReset(getCacheTheme()||theme);
}

/**
 * 初始化，并标记为application缓存
 * @param  {[type]} defTheme [默认主题]
 * @return {[type]}       [description]
 */
export function initTheme4ApplicationCache(theme) {
	cacheType = APP_TYPE;
	doReset(getCacheTheme()||theme);
}


