import './../assets/css/themes/index.scss'
import * as themeObj from './../assets/js/theme.js'
import { EventBus } from './../assets/js/event-bus.js'

const rjThemeCom = {
	/**
	 * 主题组件
	 * @param  {[type]} Vue     [description]
	 * @param  {[type]} options [自定义参数{defaultTheme, cacheType}, cacheType描述： 
	 * 1为不缓存，2为本地缓存，3为会话缓存，4：全局上下文缓存]
	 * @return {[type]}         [description]
	 */
  	install(Vue, options) {
  		options = options||{};
  		console.info("主题切换开始初始化....");
  		let cacheType = options.cacheType||1;
  		switch (cacheType) {
  		case 1:
  			themeObj.initTheme(options.defaultTheme);
  			break;
  		case 2:
  			themeObj.initTheme4LocalCache(options.defaultTheme);
  			break;
  		case 3:
  			themeObj.initTheme4SessionCache(options.defaultTheme);
  			break;
  		case 4:
  			themeObj.initTheme4ApplicationCache(options.defaultTheme);
  			break;
  		default: 
  			throw "cacheType not legitimate"; 
  		}

		Vue.mixin({
			data() {
				return {
					rjTheme: {
						obj: themeObj,
						current: ''
					}
				}
			},
			created() {
				let self = this;
				//每次进来都取缓存的
				self.rjTheme.current = themeObj.getCacheTheme(false);
				//监听变化主题
				EventBus.$on('rj-theme-change', theme => {
				  self.rjTheme.current = theme;
				});
			}
		})
      	console.info("主题切换初始化结束....");
  	}
}
// 这里的判断很重要
if (typeof window !== 'undefined' && window.Vue) { 
    window.Vue.use(rjThemeCom) 
}
export default rjThemeCom;