const path = require('path');

const HtmlWebpackPlugin = require('html-webpack-plugin');
const webpack = require('webpack');

/*去掉开发环境下的配置
ExtractTextPlugin：提取样式到css文件
webpack-bundle-analyzer：webpack打包文件体积和依赖关系的可视化
CommonsChunkPlugin：提取通用模块文件
提取manifest:让提取的公共js的hash值不要改变
压缩js，css，图片*/
const ExtractTextPlugin = require('extract-text-webpack-plugin');

const { BundleAnalyzerPlugin } = require('webpack-bundle-analyzer');

const CompressionWebpackPlugin = require("compression-webpack-plugin");

const UglifyJsPlugin = require('uglifyjs-webpack-plugin')

const OptimizeCSSPlugin = require('optimize-css-assets-webpack-plugin');

const assetRoot = 'dist-themes';

const pathApp = path.resolve(__dirname, assetRoot);

module.exports = {
  entry: {
  	"rj-theme":['./src/main.js',"babel-polyfill"] 
  },
  output: {
    filename: '[name].js',
    path: pathApp
  },
  devtool: false,
  plugins: [
    /*new UglifyJsPlugin({
        uglifyOptions: {
            compress: {
                warnings: false,
                drop_debugger: true,
                drop_console: true
            }
        },
        sourceMap: true,
        parallel: true
    }),
    new CompressionWebpackPlugin({
        cssProcessorOptions: {
            safe: true,
            map: {
                inline: false
            }
        }
    }),*/
    new HtmlWebpackPlugin({
      filename: path.resolve(pathApp, 'index.html'),
      template: 'index.html',
      inject: true,
      minify: {
         removeComments: true,
         collapseWhitespace: true,
         removeRedundantAttributes: true,
         useShortDoctype: true,
         removeEmptyAttributes: true,
         removeStyleLinkTypeAttributes: true,
         keepClosingSlash: true,
         minifyJS: true,
         minifyCSS: true,
         minifyURLs: true,
     }
    }),
    new webpack.optimize.CommonsChunkPlugin({
      name: 'vendor',
      minChunks: function (module, count) {
        return (
          module.resource &&
          /\.js$/.test(module.resource) &&
          module.resource.indexOf(
            path.resolve(__dirname, `node_modules`)
          ) === 0
        )
      }
    }),
    //new BundleAnalyzerPlugin({ analyzerPort: 8919 }),
     new webpack.optimize.CommonsChunkPlugin({
       names: ['manifest'],
       filename: 'manifest.bundle.js',
     }),
     new ExtractTextPlugin({
      filename: 'rj-theme.css',
      allChunks: true
      }),
     new webpack.HashedModuleIdsPlugin(),
     new webpack.DefinePlugin({
        'process.env.NODE_ENV': JSON.stringify('production'),
     }),

  ],
  resolve: {
    extensions: ['.js', '.vue', '.json'],
    alias: {
      'vue$': 'vue/dist/vue.esm.js'
    }
  },
  module:{
    rules: [
      {
        test: /\.vue$/,
        loader: 'vue-loader',
        options: {
	        loaders: {
	            scss: 'style-loader!css-loader!sass-loader',
	            sass: 'style-loader!css-loader!sass-loader?indentedSyntax'
	        },
	      }
      },
      {
        test: /\.js$/,
        loader: 'babel-loader',
        exclude: [path.resolve(__dirname, 'node_modules'), path.resolve(__dirname, 'theme')],
        include: [path.resolve(__dirname, 'src')]
      },
      {
          test: /\.css$/,
          exclude: [path.resolve(__dirname, 'node_modules'), path.resolve(__dirname, 'theme')],
          use: ExtractTextPlugin.extract({
            fallback: "style-loader",
            use: "css-loader"
          })
      },
      {
        test: /\.scss$/,
          use: [
            'vue-style-loader',
            'css-loader',
            {
           loader: 'sass-loader',
           options: {
            //golbal scss
             //data: `$color: red;`
           }
        }
          ]
      },
      {
        test:/\.(svg|png|gif|jpg)$/,
        loader: 'url-loader',
        exclude: [path.resolve(__dirname, 'node_modules'), path.resolve(__dirname, 'theme')]
      },
      {
        test: /\.(woff|woff2|eot|ttf|otf)$/,
        loader: 'url-loader',
        exclude: [path.resolve(__dirname, 'node_modules'), path.resolve(__dirname, 'theme')]
      },
      {
        test: /\.xml$/,
        use: [
          'xml-loader'
        ]
      }
    ]
  }
};